<?php
/**
 * Plugin Name: WooCommerce Shipping Phone
 * Description: Adds a phone number field to WooCommerce’s shipping address.
 * Author: Blitz Informàtica, S.L.
 * Author URI: https://www.infoblitz.com/
 * Version: 0.1.0
 * Text Domain: woocommerce-shipping-phone
 * Domain Path: /languages/
 *
 * @package WC-Shipping-Phone
 *
 * WC requires at least: 3.5.3
 * WC tested up to: 3.5.3
 */

defined( 'ABSPATH' ) or exit;

if ( !class_exists( 'WC_Shipping_Phone' ) ):

class WC_Shipping_Phone {
    private static $instance;

    private function __construct() {
        add_action( 'plugins_loaded', array( $this, 'load_textdomain') );

        add_filter( 'woocommerce_checkout_fields', array( $this, 'add_phone_frontend_shipping_field' ) );
        add_filter( 'woocommerce_admin_shipping_fields', array( $this, 'add_phone_admin_shipping_field' ) );
        add_filter( 'woocommerce_get_order_address', array( $this, 'add_phone_to_shipping_address' ), 10, 3 );
        add_action( 'woocommerce_checkout_create_order', array( $this, 'add_shipping_phone_meta_data_from_checkout' ), 10, 2 );

        add_filter( 'woocommerce_rest_shop_order_schema', array( $this, 'add_phone_to_rest_schema') );
        add_filter( 'woocommerce_rest_prepare_shop_order_object', array( $this, 'add_phone_to_rest_response' ), 10, 3 );
        add_filter( 'woocommerce_rest_pre_insert_shop_order_object', array( $this, 'add_shipping_phone_meta_data_from_rest' ), 10, 3 );
    }

    public static function getInstance() {
        if ( ! self::$instance ) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    public function load_textdomain() {
        load_plugin_textdomain( 'woocommerce-shipping-phone', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
    }

    public function add_phone_frontend_shipping_field( $fields ) {
        $fields['shipping']['shipping_phone'] = array(
                'label' => __( 'Phone', 'woocommerce-shipping-phone' ),
		'required'     => true,
		'type'         => 'tel',
		'class'        => array( 'form-row-wide' ),
		'validate'     => array( 'phone' ),
		'autocomplete' => 'tel',
		'priority'     => 100,

        );
        return $fields;
    }

    public function add_phone_admin_shipping_field( $fields ) {
        $fields['phone'] = array(
            'label' => __( 'Phone', 'woocommerce-shipping-phone' ),
            'show' => true,
        );
        return $fields;
    }

    public function add_phone_to_shipping_address( $address, $type, $order ) {
        if ( $type === 'shipping' ) {
            $address['phone'] = $this->get_shipping_phone( $order );
        }
        return $address;
    }

    public function add_phone_to_rest_schema( $properties ) {
        $properties['shipping']['properties']['phone'] = array(
            'description' => __( 'Phone.', 'woocommerce-shipping-phone' ),
            'type' => 'string',
            'context' => array( 'view', 'edit' ),
        );
        return $properties;
    }

    public function add_phone_to_rest_response( $response, $item, $request ) {
        if ( ! $response instanceof WP_REST_Response ) {
            return $response;
        }
        if ( array_key_exists( 'shipping', $response->data ) ) {
            $response->data['shipping']['phone'] = $this->get_shipping_phone( $item );
        }
        return $response;
    }

    public function add_shipping_phone_meta_data_from_checkout( $order, $data ) {
        if ( isset( $data['shipping_phone'] ) ) {
            $this->add_shipping_phone( $order, $data['shipping_phone'] );
        }
    }

    public function add_shipping_phone_meta_data_from_rest( $order, $request, $creating ) {
        $shipping = $request['shipping'];
        if ( ! is_null( $shipping ) && array_key_exists( 'phone', $shipping ) ) {
            $this->add_shipping_phone( $order, $shipping['phone'] );
        }
        return $order;
    }

    private function get_shipping_phone( $order ) {
        return $order->get_meta( '_shipping_phone' );
    }

    private function add_shipping_phone( $order, $nin ) {
        $order->add_meta_data( '_shipping_phone', $nin, true ); 
    }
}

WC_Shipping_Phone::getInstance();

endif;
